==> open-autonomy-0.12.1.tar.gz: open-autonomy-0.12.1/docs/advanced_reference/on_chain_addresses.md <==
# List of contract addresses

## Polygon (137)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://polygonscan.com/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://polygonscan.com/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://polygonscan.com/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://polygonscan.com/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://polygonscan.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Polygon Mumbai (80001)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xf805DfF246CC208CD2F08ffaD242b7C32bc93623`](https://mumbai.polygonscan.com/address/0xf805DfF246CC208CD2F08ffaD242b7C32bc93623) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x43d28764bB39936185c84906983fB57A8A905a4F`](https://mumbai.polygonscan.com/address/0x43d28764bB39936185c84906983fB57A8A905a4F) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x9dEc6B62c197268242A768dc3b153AE7a2701396`](https://mumbai.polygonscan.com/address/0x9dEc6B62c197268242A768dc3b153AE7a2701396) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xB575dd20281c63288428DD58e5f579CC7d6aae4d`](https://mumbai.polygonscan.com/address/0xB575dd20281c63288428DD58e5f579CC7d6aae4d) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://mumbai.polygonscan.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Gnosis (100)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x9338b5153AE39BB89f50468E608eD9d764B755fD`](https://gnosisscan.io/address/0x9338b5153AE39BB89f50468E608eD9d764B755fD) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://gnosisscan.io/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://gnosisscan.io/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://gnosisscan.io/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://gnosisscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Chiado (10200)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x31D3202d8744B16A120117A053459DDFAE93c855`](https://gnosis-chiado.blockscout.com/address/0x31D3202d8744B16A120117A053459DDFAE93c855) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x29086141ecdc310058fc23273F8ef7881d20C2f7`](https://gnosis-chiado.blockscout.com/address/0x29086141ecdc310058fc23273F8ef7881d20C2f7) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0xeB49bE5DF00F74bd240DE4535DDe6Bc89CEfb994`](https://gnosis-chiado.blockscout.com/address/0xeB49bE5DF00F74bd240DE4535DDe6Bc89CEfb994) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x5BA58970c2Ae16Cf6218783018100aF2dCcFc915`](https://gnosis-chiado.blockscout.com/address/0x5BA58970c2Ae16Cf6218783018100aF2dCcFc915) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://gnosis-chiado.blockscout.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

==> open-autonomy-0.13.1.tar.gz: open-autonomy-0.13.1/docs/advanced_reference/on_chain_addresses.md <==
# List of contract addresses

## Polygon (137)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xE3607b00E75f6405248323A9417ff6b39B244b50`](https://polygonscan.com/address/0xE3607b00E75f6405248323A9417ff6b39B244b50) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://polygonscan.com/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://polygonscan.com/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5`](https://polygonscan.com/address/0x34C895f302D0b5cf52ec0Edd3945321EB0f83dd5) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://polygonscan.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Polygon Mumbai (80001)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0xf805DfF246CC208CD2F08ffaD242b7C32bc93623`](https://mumbai.polygonscan.com/address/0xf805DfF246CC208CD2F08ffaD242b7C32bc93623) |
| `Service Manager` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x43d28764bB39936185c84906983fB57A8A905a4F`](https://mumbai.polygonscan.com/address/0x43d28764bB39936185c84906983fB57A8A905a4F) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x9dEc6B62c197268242A768dc3b153AE7a2701396`](https://mumbai.polygonscan.com/address/0x9dEc6B62c197268242A768dc3b153AE7a2701396) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0xB575dd20281c63288428DD58e5f579CC7d6aae4d`](https://mumbai.polygonscan.com/address/0xB575dd20281c63288428DD58e5f579CC7d6aae4d) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://mumbai.polygonscan.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Gnosis (100)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x9338b5153AE39BB89f50468E608eD9d764B755fD`](https://gnosisscan.io/address/0x9338b5153AE39BB89f50468E608eD9d764B755fD) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8`](https://gnosisscan.io/address/0xa45E64d13A30a51b91ae0eb182e88a40e9b18eD8) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0x04b0007b2aFb398015B76e5f22993a1fddF83644`](https://gnosisscan.io/address/0x04b0007b2aFb398015B76e5f22993a1fddF83644) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE`](https://gnosisscan.io/address/0x3C1fF68f5aa342D296d4DEe4Bb1cACCA912D95fE) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x3d77596beb0f130a4415df3D2D8232B3d3D31e44`](https://gnosisscan.io/address/0x3d77596beb0f130a4415df3D2D8232B3d3D31e44) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://gnosisscan.io/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |

## Chiado (10200)
| Name | Environment Variable | Address |
| ---- | -------------------- | ------- |
| `Service Registry L 2` | `CUSTOM_SERVICE_REGISTRY_ADDRESS` | [`0x31D3202d8744B16A120117A053459DDFAE93c855`](https://gnosis-chiado.blockscout.com/address/0x31D3202d8744B16A120117A053459DDFAE93c855) |
| `Service Registry Token Utility` | `CUSTOM_SERVICE_REGISTRY_TOKEN_UTILITY_ADDRESS` | [`0xc2c7E40674f1C7Bb99eFe5680Efd79842502bED4`](https://gnosis-chiado.blockscout.com/address/0xc2c7E40674f1C7Bb99eFe5680Efd79842502bED4) |
| `Service Manager Token` | `CUSTOM_SERVICE_MANAGER_ADDRESS` | [`0xc965a32185590Eb5a5fffDba29E96126b7650eDe`](https://gnosis-chiado.blockscout.com/address/0xc965a32185590Eb5a5fffDba29E96126b7650eDe) |
| `Gnosis Safe Multisig` | `CUSTOM_GNOSIS_SAFE_PROXY_FACTORY_ADDRESS` | [`0xeB49bE5DF00F74bd240DE4535DDe6Bc89CEfb994`](https://gnosis-chiado.blockscout.com/address/0xeB49bE5DF00F74bd240DE4535DDe6Bc89CEfb994) |
| `Gnosis Safe Same Address Multisig` | `CUSTOM_GNOSIS_SAFE_SAME_ADDRESS_MULTISIG_ADDRESS` | [`0x5BA58970c2Ae16Cf6218783018100aF2dCcFc915`](https://gnosis-chiado.blockscout.com/address/0x5BA58970c2Ae16Cf6218783018100aF2dCcFc915) |
| `Multisend` | `CUSTOM_MULTISEND_ADDRESS` | [`0x40A2aCCbd92BCA938b02010E17A5b8929b49130D`](https://gnosis-chiado.blockscout.com/address/0x40A2aCCbd92BCA938b02010E17A5b8929b49130D) |
